@@ -7,7 +7,7 @@ class SDK:
         self._sdk = None
 
         # Se verifica la variable de entorno:
-        if _test: 
+        if _test != None: 
             test_sdk = _test
         else:
             test_env = os.getenv('TEST')
